/* defines.h -- limit and constant character macros 
 *
 * $Id: defines.h,v 1.32 1998/11/10 22:37:34 ccarp Exp $
 * 
 * runas - execute a single command as a different user and/or group
 * Copyright (C) 1998 Chris Carpinello
 *
 * This program is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 * Send all bugs, changes, and problems to the maintainer listed in
 * "runas --info" output.
 */

/* Release version and date information */
#include "version.h"

/* ANSI prototyping */
#ifndef  __P
#if defined (__cplusplus) || defined (__STDC__)
#define __P(args)           args
#else
#define __P(args)           ()
#endif
#endif /* __P */

/* ANSI constant definition */
#ifndef __STDC__
#define const 
#endif

#define __pathalloc(size)   pathalloc(size, __FILE__, __LINE__)
#define __stralloc(size)    stralloc(size, __FILE__, __LINE__)
#define __ecmalloc(size)    errorCheckMalloc(size, __FILE__, __LINE__)

/* 
 * Use atouid and atogid as uid_t/gid_t ranges vary in size from an 
 * unsigned short to an unsigned long depending on the platform.
 *
 * For Linux systems using glibc (LIBC6), uid_t/gid_t is actually expanded
 * to a 32-bit value when the kernel only supports a 16-bit value.
 * We don't want the expansion to occur, so we cast the value
 * returned from atoi as an unsigned short (__kernel_uid_t).  We don't
 * include <asm/posix_types.h> directly on Linux platforms (to define
 * __kernel_uid_t) as this header also redefines types that we do not want 
 * redefined.
 *
 * According to Alan Cox, the Linux kernel should support a 32-bit uid_t
 * in the 2.3.x kernel release.  
 *
 * According to Ulrich Drepper <drepper@cygnus.com>, glibc version 2.0.99 
 * and above should fix this problem on Linux platforms.
 */
#if ((Linux == 1) && (MAJORVER == 2) && (MINORVER < 3) &&(__GLIBC__ >= 2))
#define atouid(a) (unsigned short) atoi(a)
#else
#define atouid(a) (sizeof(uid_t) == sizeof(long)) \
? (uid_t) atol(a) \
: (uid_t) atoi(a) 
#endif /* __kernel_uid_t */

#ifdef Linux
#define atogid(a) (unsigned short) atoi(a)
#else
#define atogid(a) (sizeof(gid_t) == sizeof(long)) \
? (gid_t) atol(a) \
: (gid_t) atoi(a) 
#endif /* __kernel_gid_t */

/* C++-like function declarationisms */
#define PUBLIC
#define PRIVATE static

/* Maintainer of runas */
#define MAINTAINER "Chris Carpinello <carpinello@mindspring.com>"

/* Usage and command line arguments */
#define USAGE_MSG "Usage:\nrunas [environment flag] [option flags] [ -[user[.]group]] ] command [args]\n  Environment flag is one of:\n"
#define USAGE_MSG1 "  --preserve         Preserve the environment when running command."
#define USAGE_MSG2 "  --sanitize         Sanitize environment when running command."
#define USAGE_MSG3 "  --login            As --sanitize, but command is invoked as a login shell\n                       if command is a restricted shell.\n\n  Option flags:\n  --which            Displays the command that will actually be chosen from\n                       $PATH to run, but does not actually run the command.\n\n  user               uid or login name to run command as\n  group              gid or group name to run command as\n  command            file to execute as specified user and/or group. \n  args               command line arguments passed to command.\nrunas --access       Display commands available to run via runas and exit.\nrunas --help         Display usage information and exit.\nrunas --info         Display detailed default behavior and compile-time\n                       user-option information suitable for a bug report\n                       and exit.\nrunas --version      Display version, copyright and warranty information\n                       and exit.\n"
#define USAGE_OPTION_ACCESS    "--access"
#define USAGE_OPTION_HELP      "--help"
#define USAGE_OPTION_INFO      "--info"
#define USAGE_OPTION_VERSION   "--version"
#define USAGE_OPTION_PRESERVE  "--preserve"
#define USAGE_OPTION_SANITIZE  "--sanitize"
#define USAGE_OPTION_LOGIN     "--login"
#define USAGE_OPTION_WHICH     "--which"

/* access messages */
#define NOLOG_NOPRIVMSG "No priviledge for command."
#define ACCESS_MSGDELIMITER    "-------------------------------------------------------------------------\n"

/* default uid used when none specified on command line.  should be 0. */ 
#define DEFAULT_UID (uid_t)0

/* default umask set when running a command */
#define ADMIN_UMASK (mode_t)022   /* mode 750 */

/* Weak attempt to deal with a boolean type */
#define BOOLEAN int

#ifdef TRUE
#undef TRUE
#endif
#define TRUE         1
#ifdef FALSE
#undef FALSE
#endif
#define FALSE        0

/* System character and string constants */
#define SPACE    32                       /* ASCII decimal for space */
#define COMMA    44                       /* ASCII decimal for comma */
#define NEWLINE  "\n"                     /* needle in a haystack    */
#define NULLTTY  "(null tty)"             /* /dev/nulltty            */
#define DEVNULL  "/dev/null"              /* /dev/null               */
#define ETCSHELLS "/etc/shells"

/* define maximum lengths for user and group names */
/*#ifdef MAXLOGNAME 
#define MAXUSERNAMELEN MAXLOGNAME
#else */
#define MAXUSERNAMELEN  16	/* 8 on most systems, 16 on a few */
/* #endif MAXUERNAMELEN */
#define MAXGROUPNAMELEN 16	/* 8 on most systems, 16 on a few */
#define MAXUSERNAMESIZE  (MAXUSERNAMELEN + 1)
#define MAXGROUPNAMESIZE (MAXGROUPNAMELEN + 1)

/*
 * Determine the maximum path length.  
 *
 * If neither PATH_MAX nor MAXPATHLEN are defined, then a limit is determined
 * at runtime using pathconf(_PC_PATH_MAX).  If the value returned by
 * pathconf is indeterminate, then a very large number defined by 
 * RUNAS_PATH_MAX is used.
 */
#ifdef PATH_MAX
#define MAXIMUMPATHLEN PATH_MAX   /* POSIX */
#else
#ifdef MAXPATHLEN
#define MAXIMUMPATHLEN MAXPATHLEN /* BSD */
#endif /* MAXPATHLEN */
#endif /* PATH_MAX */
#define RUNAS_PATH_MAX 32767 /* ludicrous, but safe(?) value */

/* exit return values */
#ifndef EXIT_SUCCESS
#define EXIT_SUCCESS    0       /* Successful exit status.  */
#endif /* EXIT_SUCCESS */
#ifndef EXIT_FAILURE
#define EXIT_FAILURE    1       /* Failed exit status.  */
#endif /* EXIT_FAILURE */

/* setenv behavior */
#if (HAVE_PUTENV != 1)
#define OVERWRITE 1
#define PRESERVE  0
#endif /* HAVE_PUTENV */

/* size of reason buffer */
#define MAXREASONSIZE 257        
/* maximum length of NULL terminated reason */
#define MAXREASONLEN (MAXREASONSIZE - 1)

/* size of error message buffer */
#define ERRORSIZE 1025
/* maximum length of NULL-terminated error message */
#define ERRORLEN (ERRORSIZE - 1)

/* POSIX.2 defines shell files can have 2048 byte length files */
#define MAX_ACCESS_ENTRYSIZE 2049 
#define MAX_ACCESS_ENTRYLEN (MAX_ACCESS_ENTRYSIZE - 1)
#define MAX_ACCESS_ELEMENTSIZE 1025
#define MAX_ACCESS_ELEMENTLEN (MAX_ACCESS_ELEMENTSIZE - 1)

/* Delimiter to mark the end of the Ok_Folks array */
#define OK_FOLKS_DELIMITER (uid_t) -1

/* getcwd macro */
#if (HAVE_GETCWD != 1)
#define getcwd(pwd, size) getwd(pwd)
#endif /* HAVE_GETCWD */

/* memcpy macro */
#if (HAVE_MEMCPY == 1)
#define bcopy(from, to, len) memcpy(to, from, len)
#endif /* HAVE_MEMCPY */

/* memset macro */
#if (HAVE_MEMSET == 1)
#define bzero(addr, cnt) memset(addr, 0, cnt)
#endif /* HAVE_MEMSET */

/* snprintf macro */
#if (HAVE_SNPRINTF == 1)
#define esprintf(string, format, args...) snprintf(string, ERRORLEN, format, ## args) 
#else
#define esprintf(string, format, args...) sprintf(string, format, ## args) 
#define snprintf(string, len, format, args...) sprintf(string, format, ## args)
#endif /* HAVE_SNPRINTF */

/*
 * Anything below this line is generated automatically by the Makefile.
 * Do not edit!
 */

/* end defines.h */

#define COMPILE_CC      "gcc"
#define COMPILE_CFLAGS  " -g -O2 -ansi -Wall"
#define COMPILE_DEFINES " -DUSE_SYSLOG=1 -DACF_PATH=\"/usr/local/etc/runas.access\" -DNOSHELL=\"/bin/false\" -D_GNU_SOURCE -DLinux=1 -DSYS=\"Linux\" -DMAJORVER=2 -DMINORVER=0 -DBUGFIXVER=33 -DSTDC_HEADERS=1 -DHAVE_UNISTD_H=1 -DHAVE_MALLOC_H=1 -DHAVE_STDLIB_H=1 -DHAVE_SYSLOG_H=1 -DHAVE_ARPA_NAMESER_H=1 -DHAVE_LIMITS_H=1 -DHAVE_NETDB_H=1 -DHAVE_GETCWD=1 -DHAVE_INITGROUPS=1 -DHAVE_MEMSET=1 -DHAVE_PUTENV=1 -DHAVE_SETREUID=1 -DHAVE_SNPRINTF=1 -DHAVE_GETUSERSHELL=1 -DHAVE_SETNETGRENT=1  "
#define COMPILE_LIBS    " "
#define COMPILE_LDFLAGS " -static"
