/* log.h -- syslog limit and constant character macros
 *
 * $Id: log.h,v 1.7 1998/10/26 19:55:53 ccarp Exp $
 * 
 * runas - execute a single command as a different user and/or group
 * Copyright (C) 1998 Chris Carpinello
 *
 * This program is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 * Send all bugs, changes, and problems to the maintainer listed in
 * "runas --info" output.
 */
/* Syslog messages and arguments */
#define SYSLOG_NOPRIVMSG       "on %s in %s: NO PRIVILEDGE for %s for command:"
#define SYSLOG_NOPRIVMSG_ARGS  tty, cwd, user
#define SYSLOG_REASONMSG       "on %s in %s from %s to %s.%s for {%s}:"
#define SYSLOG_REASONMSG_ARGS  tty, cwd, fromuser, touser, togroup, reason
#define SYSLOG_MSG             "on %s in %s from %s to %s.%s:"
#define SYSLOG_MSG_ARGS        tty, cwd, fromuser, touser, togroup

/* maximum length of syslog label allowed */
#define SYSLOG_LABEL_MAX 64

/* 
 * Define the syslog facility and priority to use.  When available, use
 * LOG_AUTHPRIV instead of LOG_AUTH, as LOG_AUTHPRIV has a "secure" log.
 */
#ifdef LOG_AUTHPRIV
#define SYSLOG_FACILITY LOG_AUTHPRIV	    /* Facility to syslog() to      */
#else
#define SYSLOG_FACILITY LOG_AUTH	    /* Facility to syslog() to      */
#endif /* LOG_AUTHPRIV */
#define SYSLOG_PRIORITY_OKPRIV LOG_NOTICE   /* authorized runas usage       */
#define SYSLOG_PRIORITY_NOPRIV LOG_ALERT    /* unauthorized runas usage     */
#define SYSLOG_OPTIONS  LOG_CONS|LOG_NDELAY /* Logging options for syslog() */

/* maximum size of syslog msg including date, label, and field separaters */
#ifdef AIX
 #define SYSLOG_BUFSIZE 1024
 #define SYSLOG_DIR "/var/adm"
#endif /* AIX */

#ifdef FreeBSD
 #define SYSLOG_BUFSIZE 1024
 #define SYSLOG_DUR "/var/log"
#endif /* FREEBSD */

#ifdef HPUX
 #if (MAJORVER == 9)
  #define SYSLOG_BUFSIZE 2560
  #define SYSLOG_DIR "/var/adm"
 #endif /* MAJORVER=9 */
 #if (MAJORVER == 10)
  #define SYSLOG_BUFSIZE 1920
  #define SYSLOG_DIR "/var/adm/syslog"
 #endif /* MAJORVER=10 */
#endif /* SYS=HPUX */

#ifdef IRIX 
 #if (MAJORVER == 5)
  #define SYSLOG_BUFSIZE 512
  #define SYSLOG_DIR "/var/adm"
 #endif /* MAJORVER=5 */
 #if (MAJORVER == 6)
  #define SYSLOG_BUFSIZE 512
  #define SYSLOG_DIR "/var/adm"
 #endif /* MAJORVER=6 */
#endif /* SYS=IRIX */

#ifdef Linux
 #define SYSLOG_BUFSIZE 1024
 #define SYSLOG_DIR "/var/log"
#endif /* SYS=Linux */

#ifdef SunOS 
 #if (MAJORVER == 4)
  #define SYSLOG_BUFSIZE 1024
  #define SYSLOG_DIR "/var/log"
 #endif /* MAJORVER=4 */
 #if (MAJORVER == 5)
  #define SYSLOG_BUFSIZE 1024
  #define SYSLOG_DIR "/var/log"
 #endif /* MAJORVER=5 */
#endif /* SYS=SunOS */

#ifdef Ultrix
 #define SYSLOG_BUFSIZE 256
#endif /* ULTRIX4 */

#if __GLIBC__ >= 2
 #define SYSLOG_BUFSIZE 1024
 #define SYSLOG_DIR "/var/log"  
#endif /* __GLIBC__ >= 2 */

/* best guess definitions for systems with unknown maximum syslog msg size */
#ifndef SYSLOG_BUFSIZE
 #define SYSLOG_BUFSIZE 1024
#endif /* SYSLOG_BUFSIZE */

#ifndef SYSLOG_DIR
 #define SYSLOG_DIR "/var/log"
#endif /* SYSLOG_DIR */
/* minimum buffer usage for date/time and spacing */
#define SYSLOG_FIXEDLEN 19 /* 15 for date/time, 4 for 3 spaces and a colon */
