/* proto.h -- function prototypes 
 *
 * $Id: proto.h,v 1.15 1998/10/26 19:55:53 ccarp Exp $
 * 
 * runas - execute a single command as a different user and/or group
 * Copyright (C) 1998 Chris Carpinello
 *
 * This program is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 * Send all bugs, changes, and problems to the maintainer listed in
 * "runas --info" output.
 */

#ifndef _RUNAS_PROTO_H
#define _RUNAS_PROTO_H

#if defined(__cplusplus)
extern "C" {
#endif /* __cplusplus */

/* from acf.c */
#if (USE_ACF == TRUE)
PUBLIC int checkCommandAccess  __P((int *argc, char **argv, char *runuidptr, char *rungidptr, const char *user));
PUBLIC void freeAcfList        __P((void));
PUBLIC int inAccessList        __P((alist *accesslist, const char *user));
PUBLIC int parseAcf            __P((uid_t myuid, gid_t mygid));
PUBLIC void printAcfCommand    __P((accessentry *entry, int needACF));
PUBLIC void security           __P((void));
#endif /* USE_ACF */

/* from log.c */
#if (USE_SYSLOG == 1)
PUBLIC void initSyslog         __P((const char *label));
PUBLIC void delimitArgs        __P((char *msg, char * const *args));
#if (USE_ACF == TRUE)
PUBLIC void promptReason       __P((void));
#endif /* USE_ACF && USE_SYSLOG */
PUBLIC void syslogCleanUp      __P((void));
PUBLIC void syslogCommand      __P((uid_t myuid, uid_t myeuid, uid_t runuid, gid_t rungid, int argc , char * const *argv));
PUBLIC void syslogCommandNOPRIV __P((int *argc, char **argv, uid_t myuid, uid_t myeuid, char *user));
PUBLIC void syslogMsg          __P((int priority, const char *msg));
#endif /* USE_SYSLOG */

/* from misc.c */
PUBLIC void *errorCheckMalloc  __P((size_t size, const char *file, int line));
PUBLIC void errorMsg           __P((char *uhoh, BOOLEAN freeuhoh));
PUBLIC void errorPMsg          __P((const char *uhoh));
PUBLIC void exitOK             __P((void));
PUBLIC BOOLEAN isanumber       __P((const char *s));
PUBLIC BOOLEAN isrshell        __P((const char *shell));
PUBLIC char *pathalloc         __P((size_t *size, const char *file, int line));
PUBLIC void setenvar           __P((const char *envar, const char *enval));
PUBLIC char *stralloc          __P((size_t size, const char *file, int line));
PUBLIC char *strtoken          __P((char **string, char delimiter));
PUBLIC char *which             __P((const char *filename)); 
PUBLIC char *basename          __P((const char *filename));  
PUBLIC void validateGroup      __P((char *group));
PUBLIC void validateUser       __P((char *user));
#if (USE_ACF == TRUE)
PUBLIC void cleanString        __P((char *string));
PUBLIC int convertToBoolean    __P((const char *string));
PUBLIC void removeOptions      __P((int *argc, char **argv));
#endif /* USE_ACF */
#if (USE_SYSLOG == TRUE)
PUBLIC char *getCurrentWorkingDirectory  __P((uid_t myuid, uid_t myeuid));
#endif /* USE_SYSLOG */
#if (HAVE_GETUSERSHELL != 1)
PUBLIC void setusershell       __P((void));
PUBLIC void endusershell       __P((void));
PUBLIC char *getusershell      __P((void));
#endif /* HAVE_GETUSERSHELL */

/*
 * System-specific function prototypes that should be defined by a vendor
 * somewhere in /usr/include but aren't.  These are defined mainly to
 * keep -Wall and lint from complaining heavily.  If any prototypes
 * defined here cause compilation problems, delete them.
 */

#ifdef AIX
int initgroups          __P((const char *, gid_t));
int getnetgrent         __P((char **machinep, char **userp, char **domainp));
int setnetgrent         __P((char *netgroup));
int setreuid            __P((uid_t ruid, uid_t euid));
int snprintf            __P((char *str, size_t n, const char *format, ... ));
int strncasecmp         __P((const char *s1, const char *s2, size_t n));
#if ((MAJORVER == 3) || ((MAJORVER == 4) && (MINORVER <= 1)))
/* AIX 4.2 and above define these prototypes */
int openlog             __P((const char *, int, int));
int closelog            __P((void));
int syslog              __P((int, const char *, ...));
#endif /* MAJORVER=4 */
#endif /* SYS=AIX */

#ifdef HPUX
#if (MAJORVER == 9)
int closelog            __P((void));
int getnetgrent         __P((char **machinep, char **userp, char **domainp));
int openlog             __P((const char *, int, int));
int setnetgrent         __P((char *netgroup));
int syslog              __P((int, const char *, ...));
#endif /* MAJORVER=9 */

#if (MAJORVER == 10)
int getnetgrent         __P((char **machinep, char **userp, char **domainp));
int setnetgrent         __P((char *netgroup));
int snprintf            __P((char *str, size_t n, const char *format, ... ));
#endif /* MAJORVER=10 */
#endif /* SYS=HPUX */

#ifdef IRIX
#if (MAJORVER == 6)
void endusershell       __P((void));
int fileno              __P((FILE *stream));
char *getusershell      __P((void));
int initgroups          __P((const char *user, gid_t group));
int putenv              __P((const char *)); 
int setreuid            __P((uid_t, uid_t));
void setusershell       __P((void));
char* strdup            __P((const char *));
int strncasecmp         __P((const char *s1, const char *s2, size_t n));
#if !defined(__cplusplus)
int lstat               __P((char *path, struct stat *buf));
#endif /* __cplusplus */
#endif /* MAJORVER=6 */
#endif /* SYS=IRIX */

#ifdef Linux
int fileno              __P((FILE *stream));
void endnetgrent        __P((void));
int getnetgrent         __P((char **, char **, char **));
int initgroups          __P((const char *user, gid_t group));
int putenv              __P((const char *)); 
int setreuid            __P((uid_t, uid_t));
int snprintf            __P((char *str, size_t n, const char *format, ... ));
int strncasecmp         __P((const char *, const char *, size_t));
char* strdup            __P((const char *));
char* getusershell      __P((void));
void setusershell       __P((void)); 
void endusershell       __P((void)); 
#endif /* SYS=LINUX */

#ifdef SunOS
#if (MAJORVER == 5)
int chdir               __P((const char *));
void endusershell       __P((void));
int execve              __P((const char *, char *const *, char *const *));
int fileno              __P((FILE *));
uid_t geteuid           __P((void));
gid_t getgid            __P((void));
uid_t getuid            __P((void));
char *getusershell      __P((void));
int isdigit             __P((int));
void perror             __P((const char *));
int putenv              __P((const char *string));
int setgid              __P((gid_t));
int setreuid            __P((uid_t, uid_t));
int setuid              __P((uid_t));
void setusershell       __P((void));
char *strdup            __P((const char *s1));
int strncasecmp         __P((const char *s1, const char *s2, int n));
#endif /* MAJORVER=5 */

#if (MAJORVER == 4)
void closelog           __P((void));
void endusershell       __P((void));
int fflush              __P((FILE *));
int getnetgrent         __P((char **machinep, char **userp, char **domainp));
char *getusershell      __P((void));
int initgroups          __P((char *, int));
void openlog            __P((const char *, int, int));
void perror             __P((const char *));
int putenv              __P((char *));
int setnetgrent         __P((char *netgroup));
int setreuid            __P((int, int));
void setusershell       __P((void));
int strncasecmp         __P((const char *s1, const char *s2, int n));
void syslog             __P((int, const char *, ...));
#if !defined(__cplusplus)
int fclose              __P((FILE *stream));
int fprintf             __P((FILE *, char *, ...));
int fseek               __P((FILE *stream, long offset, int whence));
int lstat               __P((char *path, struct stat *buf));
char *memset            __P((char *, int, int));
int printf              __P((char *, ...));
int sscanf              __P((char *s, char *format, ...));
#endif /* __cplusplus */
#if (SUN386 == 1)
char *getenv            __P((char *));
#endif /* SUN386 */
#endif /* MAJORVER=4 */
#endif /* SYS=SunOS */

#if defined(__cplusplus)
}
#endif /* __cplusplus */

#endif /* _RUNAS_PROTO_H */
/* end proto.h */
